@@ -27,9 +27,11 @@ from ..dataflow.custom_serialize import SerializerFiles, SerializerPdfDoc
 from ..datapoint.image import Image
 from ..mapper.maputils import cur
 from ..mapper.misc import to_image
-from ..mapper.pagestruct import to_page
 from ..utils.fs import maybe_path_or_pdf
-from .base import Pipeline
+from ..utils.logger import logger
+from ..utils.settings import names
+from .base import Pipeline, PipelineComponent, PredictorPipelineComponent
+from .common import PageParsingService
 
 
 class DoctectionPipe(Pipeline):  # pylint: disable=W0221
@@ -42,6 +44,22 @@ class DoctectionPipe(Pipeline):  # pylint: disable=W0221
     See also the explanations in :class:`base.Pipeline`
     """
 
+    def __init__(
+        self, pipeline_component_list: List[Union[PipelineComponent, PredictorPipelineComponent, PageParsingService]]
+    ):
+        if isinstance(pipeline_component_list[-1], PageParsingService):
+            self.page_parser = pipeline_component_list.pop()
+        else:
+            self.page_parser = PageParsingService(
+                text_container=names.C.WORD,
+                floating_text_block_names=[names.C.TEXT, names.C.TITLE, names.C.LIST],
+                text_block_names=[names.C.TITLE, names.C.TEXT, names.C.LIST, names.C.TAB],
+            )
+        assert all(
+            isinstance(element, (PipelineComponent, PredictorPipelineComponent)) for element in pipeline_component_list
+        )
+        super().__init__(pipeline_component_list)  # type: ignore
+
     def _entry(self, **kwargs: str) -> DataFlow:
         dataset_dataflow = kwargs.get("dataset_dataflow")
         path = kwargs.get("path")
@@ -58,7 +76,7 @@ class DoctectionPipe(Pipeline):  # pylint: disable=W0221
             elif not path_type:
                 raise ValueError("Pass only a path to a directory or to a pdf file")
 
-        file_type = kwargs.get("file_type", [".jpg", ".png"])
+        file_type = kwargs.get("file_type", [".jpg", ".png", ".tif"])
         max_datapoints = kwargs.get("max_datapoints")
 
         if isinstance(path, str):
@@ -90,7 +108,7 @@ class DoctectionPipe(Pipeline):  # pylint: disable=W0221
 
         def _to_image(dp: str) -> Optional[Image]:
             _, file_name = os.path.split(dp)
-            print(f"processing {file_name}")
+            logger.info("processing %s", file_name)
             dp = {"file_name": file_name, "location": dp}  # type: ignore
             return to_image(dp)
 
@@ -111,21 +129,20 @@ class DoctectionPipe(Pipeline):  # pylint: disable=W0221
 
         @cur  # type: ignore
         def _to_image(dp: Union[str, Dict[str, Union[str, bytes]]], dpi: Optional[int] = None) -> Optional[Image]:
-            print(f"processing {dp['file_name']}")  # type: ignore
+            logger.info("processing %s", dp["file_name"])  # type: ignore
             return to_image(dp, dpi)
 
         df = MapData(df, _to_image(dpi=300))  # type: ignore  # pylint: disable=E1120
         return df
 
-    @staticmethod
-    def dataflow_to_page(df: DataFlow) -> DataFlow:
+    def dataflow_to_page(self, df: DataFlow) -> DataFlow:
         """
         Converts a dataflow of images to a dataflow of pages
 
         :param df: Dataflow
         :return: Dataflow
         """
-        return MapData(df, to_page)
+        return self.page_parser.predict_dataflow(df)
 
     def analyze(self, **kwargs: str) -> DataFlow:
         """
