@@ -28,8 +28,11 @@ from deepdoctection.datapoint import Image
 from deepdoctection.datasets import DatasetCategories
 from deepdoctection.eval import CocoMetric, Evaluator
 from deepdoctection.extern.base import DetectionResult
-from deepdoctection.extern.tpdetect import TPFrcnnDetector
 from deepdoctection.pipe.layout import ImageLayoutService
+from deepdoctection.utils import tensorpack_available
+
+if tensorpack_available():
+    from deepdoctection.extern.tpdetect import TPFrcnnDetector
 
 
 class TestEvaluator:
